Quip
====

Quip is a minimal web-based user interface framework for Python command-line applications.

Installation
------------

You need to install the stylus and rapydscript-ng modules via npm::

  npm install -g stylus rapydscript-ng
